MatchMaker.check_activation() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMaker.check_activation()

MatchMaker.check_activation() → bool

  Verifies that the MatchMaker is active and aborts the experiment if necessary.

  If the MatchMaker not active, the current experiment session is aborted, and the abort_page specified on initialization of the MatchMaker will be shown to participants.

  The matching methods will check for activation themselves, when called. But this may happen at a point in the experiment where participants have made considerable progress. So it may be useful to manually check for activation at an earlier stage.

  As a general rule of thumb, it may be sensible to check activation on first hiding of the landing page of an experiment. This way, participants still get a nice welcome screen, but do not invest too much time before the experiment is cancelled.